@@ -1,3 +1,5 @@
+from datetime import datetime
+
 from flask import Flask
 from flask import Response
 from flask import jsonify
@@ -16,6 +18,8 @@ class ModelEncoder(JSONEncoder):
             return data.pack()
         if isinstance(data, InstrumentedList):
             return serialize(data)
+        elif isinstance(data, datetime):
+            return data.isoformat()
         else:
             data = iserialize(data)
         return data
